contexttools.set_accidental_style_on_sequential_contexts_in_expr
================================================================

.. autofunction:: abjad.tools.contexttools.set_accidental_style_on_sequential_contexts_in_expr.set_accidental_style_on_sequential_contexts_in_expr
